##  Prerequisites
  * Administrator access to your SAP LeanIX workspace.
  * Verify that the quality seal is enabled for the application fact sheet.
  * Verify that initiative fact sheets use a lifecycle configuration that includes the End of Life phase.
